@@ -3,9 +3,11 @@ package Win32::Clipboard;
 #
 # Win32::Clipboard - Interaction with the Windows clipboard
 #
-# Version: 0.5101
+# Version: 0.52
 # Author: Aldo Calpini <dada@perl.it>
 #
+# Modified by: Hideyo Imazu <himazu@gmail.com>
+#
 #######################################################################
 
 require Exporter;       # to export the constants to the main:: space
@@ -60,7 +62,7 @@ sub AUTOLOAD {
 #######################################################################
 # STATIC OBJECT PROPERTIES
 #
-$VERSION = "0.5101";
+$VERSION = "0.5201";
 
 #######################################################################
 # FUNCTIONS
@@ -356,8 +358,12 @@ IsFormatAvailable() and GetAs() functions:
 
 =head1 AUTHOR
 
-Aldo Calpini <F<dada@perl.it>>
+This version was released by Hideyo Imazu <F<himazu@gmail.com>>.
+
+Aldo Calpini <F<dada@perl.it>> was the former maintainer.
 
 Original XS porting by Gurusamy Sarathy <F<gsar@activestate.com>>.
 
 =cut
+
+
